==> lori_sdk-0.0.8.tar.gz: lib/data/database/mobile/mobileUserDao.dart <==
import 'dart:async';

import 'package:lori_sdk/data/database/interfaces/userDao.dart';
import 'package:lori_sdk/data/models/singleton/userSingleton.dart';
import 'package:lori_sdk/data/models/user.dart';
import 'package:path/path.dart';
import 'package:sqflite/sqflite.dart';

class MobileUserDao implements UserDao {
  Database db;
  User loggedUser;

  Future open() async {
    if (db == null || !db.isOpen) {
      var databasesPath = await getDatabasesPath();
      String path = join(databasesPath, 'loriUser.db');
      db = await openDatabase(path, version: 1,
          onCreate: (Database db, int version) async {
        await db.execute('''
        create table $tableName (
          $columnId text primary key,
          $columnName text,
          $columnEmail text,
          $columnImageUrl text,
          $columnCpf text,
          $columnPhoneNumber text,
          $columnDateOfBirth text,
          $columnGender integer,
          $columnPayments text,
          $columnAddresses text
        )
      ''');
      });
    }
  }

  Future<void> insertOrUpdate(User user) async {
    var storedUser = await get();
    if (storedUser == null)
      return await insert(user);
    else
      return await update(user);
  }

  Future<void> insert(User user) async {
    await open();
    await db.insert(tableName, user.toMap());
    return UserSingleton().userChanged(user);
  }

  Future<void> update(User user) async {
    DateTime.now().millisecond;
    await open();
    await db.update(tableName, user.toMap(),
        where: '$columnId = ?', whereArgs: [user.id]);
    return UserSingleton().userChanged(user);
  }

  Future<User> get() async {
    await open();
    List<Map> maps = await db.query(tableName);
    if (maps != null && maps.length > 0) {
      var user = User();
      user.fromMap(maps.first);
      return user;
    }
    return null;
  }

  Future<void> delete() async {
    await open();
    await db.delete(tableName);
    return UserSingleton().userChanged(null);
  }
}

UserDao getUserDao() => MobileUserDao();

==> lori_sdk-0.1.10.tar.gz: lib/data/database/mobile/mobileUserDao.dart <==
import 'dart:async';

import 'package:lori_sdk/data/database/interfaces/userDao.dart';
import 'package:lori_sdk/data/models/singleton/userSingleton.dart';
import 'package:lori_sdk/data/models/user.dart';
import 'package:path/path.dart';
import 'package:sqflite/sqflite.dart';

class MobileUserDao implements UserDao {
  Database db;
  User loggedUser;

  Future open() async {
    if (db == null || !db.isOpen) {
      var databasesPath = await getDatabasesPath();
      String path = join(databasesPath, 'loriUser.db');
      db = await openDatabase(path, version: 1,
          onCreate: (Database db, int version) async {
        await db.execute('''
        create table $tableName (
          $columnId text primary key,
          $columnName text,
          $columnEmail text,
          $columnImageUrl text,
          $columnCpf text,
          $columnPhoneNumber text,
          $columnDateOfBirth text,
          $columnGender integer,
          $columnPayments text,
          $columnAddresses text
        )
      ''');
      });
    }
  }

  Future<void> insertOrUpdate(User user) async {
    var storedUser = await get();
    if (storedUser == null)
      return await insert(user);
    else
      return await update(user);
  }

  Future<void> insert(User user) async {
    await open();
    await db.insert(tableName, user.toMap());
    return UserSingleton().userChanged(user);
  }

  Future<void> update(User user) async {
    DateTime.now().millisecond;
    await open();
    await db.update(tableName, user.toMap(),
        where: '$columnId = ?', whereArgs: [user.id]);
    return UserSingleton().userChanged(user);
  }

  Future<User> get() async {
    await open();
    List<Map> maps = await db.query(tableName);
    if (maps != null && maps.length > 0) {
      var user = User();
      user.fromMap(maps.first);
      return user;
    }
    return null;
  }

  Future<void> deleteAll() async {
    await open();
    await db.delete(tableName);
    return UserSingleton().userChanged(null);
  }
}

UserDao getUserDao() => MobileUserDao();
